package com.couplet.common.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.couplet.common.core.web.domain.BaseEntity;
import com.couplet.common.domain.request.FenceUpdateRequest;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotEmpty;
import java.util.Date;

/**
 * @Author: LiJiaYao
 * @Date: 2024/3/28
 * 电子围栏类
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("couplet_fence_info")
public class Fence extends BaseEntity{

    @TableId(value = "fence_id", type = IdType.AUTO)
    /**
     * 围栏id
     */
    private Long fenceId;
    /**
     * 围栏名称
     */

    @NotEmpty(message = "围栏名称不能为空")
    private String fenceName;
    /**
     * 围栏经纬度
     */
    private String fenceLongitudeLatitude;
    /**
     * 围栏描述
     */
    @NotEmpty(message = "围栏描述不能为空")
    private String fenceDescription;
    /**
     * 是否删除
     */
    private Integer isDelete;
    /**
     * 围栏状态
     */
    private Integer fenceState;
    /**
     * 创建时间
     */
     @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
     @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createTime;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date updateTime;
    /**
     * 创建人
     */
    @NotEmpty(message = "创建人不能为空")
    private String createName;
    /**
     * 维护人
     */
    @NotEmpty(message = "维护人不能为空")
    private String maintainerName;
    /**
     * 告警状态
     */

    private Integer alarmStatus;


    /**
     * 标识
     */
    @TableField(exist = false)
    private Integer logoId;
    @TableField(exist = false)
    private String logoName;

    public static Fence updateFenceStatus(FenceUpdateRequest fenceUpdateRequest) {

        return Fence.builder()
                .fenceName(fenceUpdateRequest.getFenceName())
                .fenceDescription(fenceUpdateRequest.getFenceDescription())
                .fenceState(fenceUpdateRequest.getFenceState())
                .fenceLongitudeLatitude(fenceUpdateRequest.getFenceLongitudeLatitude())
                .createName(fenceUpdateRequest.getCrateName())
                .createTime(fenceUpdateRequest.getCreateTime())
                .isDelete(fenceUpdateRequest.getIsDelete())
                .maintainerName(fenceUpdateRequest.getMaintainerName())
                .alarmStatus(fenceUpdateRequest.getAlarmStatus())
                .updateTime(fenceUpdateRequest.getUpdateTime())
                .fenceId(fenceUpdateRequest.getFenceId())
                .build();

    }


//    public static Fence fenceInsert(FenceRequest fenceRequest) {
//
//        return Fence.builder()
//                .fenceName(fenceRequest.getFenceName())
//                .fenceLongitudeLatitude(fenceRequest.getFenceLongitudeLatitude())
//                .fenceState(fenceRequest.getFenceState())
//                .fenceDescription(fenceRequest.getFenceDescription())
//                .createTime(fenceRequest.getCreateTime())
//                .updateTime(fenceRequest.getUpdateTime())
//                .isDelete(fenceRequest.getIsDelete())
//                .alarmStatus(fenceRequest.getAlarmStatus())
//                .logoId(fenceRequest.getLogoId())
//                .build();
//    }
}
