package com.couplet.remote;

import com.couplet.common.core.constant.ServiceNameConstants;
import com.couplet.common.core.domain.Result;
import com.couplet.common.domain.Vehicle;
import com.couplet.common.domain.VehicleMiddle;
import com.couplet.remote.factory.RemoteVehicleFallbackFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(contextId = "remoteVehicleService" ,
        value = ServiceNameConstants.BUSINESS_SERVICE,
        fallbackFactory = RemoteVehicleFallbackFactory.class,
        path = "/vehicle"
)
public interface RemoteVehicleService {

    /*
     * @param null:
     * @return null
     * @author 付凡芮
     * @description 根据员工id查询员工下有哪些车
     * @date
     */
    @PostMapping("UserUnderTheVehicle/{userId}")
    public Result<List<Vehicle>> UserUnderTheVehicleList(@PathVariable(value = "userId") Long userId);


    /*
     * @param middleId:
      * @return Result<Integer>
     * @author 付凡芮
     * @description 删除员工管理的车辆
     * @date
     */
    @DeleteMapping("/{middleId}")
    public Result<Integer> deleteVehicle(@PathVariable(value = "middleId") Long middleId);


    @PostMapping
    public Result<Integer> addVehicle(@RequestBody VehicleMiddle vehicleMiddle);



    @PostMapping("vehicleAll")
    public Result<List<Vehicle>> VehicleManageList();


    @GetMapping("/findByVIN/{vin}")
    public Result<List<Vehicle>> findByVIN(@PathVariable("vin") String vin);

    @GetMapping("onOrOutLineByVIN")
    public Integer onOrOutLineByVIN(@RequestParam("params") String params);


}
