package com.couplet.common.system.remote;

import com.couplet.common.core.constant.ServiceNameConstants;
import com.couplet.common.core.domain.Result;
import com.couplet.common.system.domain.SysDept;
import com.couplet.common.system.remote.factory.RemoteDeptFallbackFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@FeignClient(contextId = "remoteDeptService" ,
        value = ServiceNameConstants.SYSTEM_SERVICE,
        fallbackFactory = RemoteDeptFallbackFactory.class,
        path = "/dept"
)
public interface RemoteDeptService {
    /**
     * 查询部门管理数据
     *
     * @param dept 部门信息
     * @return 部门信息集合
     */
    @GetMapping("/list")
    public Result list (SysDept dept);

    /**
     * 根据企业ID获取企业下部门
     *
     * @param deptId 企业ID
     * @return 企业信息，内含有部门
     */
    @GetMapping("/getSysDeptByDeptId/{deptId}")
    public Result<List<SysDept>> getSysDeptByDeptId(@PathVariable(value = "deptId") Long deptId);

    /*
     * @param dept:
      * @return Result
     * @author 付凡芮
     * @description 企业部门添加
     * @date
     */
    @PostMapping
    public Result add (@Validated @RequestBody SysDept dept);



    /*
     * @param dept:
      * @return null
     * @author 付凡芮
     * @description 企业部门修改
     * @date
     */

    @PutMapping
    public Result edit (@Validated @RequestBody SysDept dept);


    /*
     * @param null:
      * @return null
     * @author 付凡芮
     * @description 删除企业部门
     * @date
     */
    @DeleteMapping("/{deptId}")
    public Result remove (@PathVariable(value = "deptId") Long deptId);


    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 根据deptId获取部门详情
     * @date
     */
    @GetMapping(value = "/{deptId}")
    public Result getInfo (@PathVariable(value = "deptId") Long deptId);


    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 查询部门列表
     * @date
     */

    @GetMapping("/list/exclude/{deptId}")
    public Result excludeChild (@PathVariable(value = "deptId") Long deptId);


}
