package com.couplet.common.system.remote;

import com.couplet.common.core.constant.ServiceNameConstants;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.page.TableDataInfo;
import com.couplet.common.system.domain.SysUser;
import com.couplet.common.system.remote.factory.RemoteEmployeeFallbackFactory;
import lombok.extern.java.Log;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/*
 * @param null:
  * @return null
 * @author 付凡芮
 * @description 远程调用用户服务
 * @date
 */
@FeignClient(contextId = "remoteEmployeeService",
        value = ServiceNameConstants.SYSTEM_SERVICE,
        fallbackFactory = RemoteEmployeeFallbackFactory.class,
        path = "/user")
public interface RemoteEmployeeService {


    /*
     * @param user:
      * @return Result<TableDataInfo<SysUser>>
     * @author 付凡芮
     * @description 调用用户列表
     * @date
     */
    @PostMapping("/list")
    public Result<TableDataInfo<SysUser>> list (SysUser user);


   /*
    * @param user:
     * @return Result
    * @author 付凡芮
    * @description 添加用户管理
    * @date
    */
    @PostMapping
    public Result add (@Validated @RequestBody SysUser user);


    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 修改用户
     * @date
     */
    @PutMapping
    public Result edit (@Validated @RequestBody SysUser user);


    /*
     * @param userIds:
      * @return Result
     * @author 付凡芮
     * @description 删除用户
     * @date
     */
    @DeleteMapping("/{userIds}")
    public Result remove (@PathVariable(value = "userIds") Long[] userIds);

    /*
     * @param null:
      * @return null
     * @author 付凡芮
     * @description X修改用户状态
     * @date
     */
    @PutMapping("/changeStatus")
    public Result changeStatus (@RequestBody SysUser user);


    /*
     * @param deptId:
      * @return Result<List<SysUser>>
     * @author 付凡芮
     * @description 根据deptId获取企业下有那些员工
     * @date
     */
    @PostMapping("userList/{deptId}")
    public Result<List<SysUser>> userList(@PathVariable(value = "deptId") Long deptId);



}
