package com.couplet.common.system.remote.factory;

import com.couplet.common.core.domain.Result;
import com.couplet.common.system.domain.SysDept;
import com.couplet.common.system.remote.RemoteDeptService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FallbackFactory;

import java.util.List;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 企业服务降级处理
 * @date 2024/3/27 15:29
 */
@Slf4j

public class RemoteDeptFallbackFactory implements FallbackFactory<RemoteDeptService> {
    @Override
    public RemoteDeptService create(Throwable cause) {
        log.error("sys服务调用失败:{}", cause.getMessage());

        return new RemoteDeptService() {

            @Override
            public Result list(SysDept dept) {
                return null;
            }



            /**
             * 根据企业ID获取企业下部门
             *
             * @param deptId 企业ID
             * @return 企业信息，内含有部门
             */
            @Override
            public Result<List<SysDept>> getSysDeptByDeptId(Long deptId) {
                return Result.error("调用失败...."+cause.getMessage());
            }

            /*
             * @param cause:
              * @return RemoteDeptService
             * @author 付凡芮
             * @description 添加企业部门
             * @date
             */

            @Override
            public Result add(SysDept dept) {
                return Result.error("调用失败...."+cause.getMessage());
            }

            /*
             * @param dept:
              * @return Result
             * @author 付凡芮
             * @description 修改企业部门
             * @date
             */
            @Override
            public Result edit(SysDept dept) {
                return Result.error("调用失败..."+cause.getMessage());
            }

            /*
             * @param deptId:
              * @return Result
             * @author 付凡芮
             * @description 删除企业部门
             * @date
             */
            @Override
            public Result remove(Long deptId) {
                return Result.error("调用失败...."+cause.getMessage());
            }

            /*
             * @param deptId:
             * @return Result
             * @author 付凡芮
             * @description 根据deptId获取部门详情
             * @date
             */
            @Override
            public Result getInfo(Long deptId) {
                return Result.error("调用失败....."+cause.getMessage());
            }
            /*
             * @param deptId:
             * @return Result
             * @author 付凡芮
             * @description 查询部门列表
             * @date
             */
            @Override
            public Result excludeChild(Long deptId) {
                return Result.error("调用失败...."+cause.getMessage());
            }

        };

    }
}
