package com.couplet.analyze.msg.consumer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.mapper.IncidentMapper;
import com.couplet.analyze.msg.service.impl.realTimeData.RealTimeJudge;
import com.couplet.common.domain.request.RealTimeDataRequest;
import com.rabbitmq.client.Channel;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.concurrent.TimeUnit;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/4
 * @Description:
 */
@Log4j2
@Component
@RabbitListener(queues = "finByVinQueueName")
public class MsgConsumer {
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private IncidentMapper incidentMapper;

    @RabbitHandler
    public void realTimeDataConsumer(RealTimeDataRequest realTimeDataRequest, Channel channel, Message message) throws IOException {

        log.info("消息进入队列，传入的数据是:[{}]", realTimeDataRequest);

        String messageId = message.getMessageProperties().getMessageId();
        long deliveryTag = message.getMessageProperties().getDeliveryTag();
        if (!redisTemplate.hasKey("消息不丢失:" + messageId)) {
            redisTemplate.opsForValue().set("消息不丢失:" + messageId, "" + deliveryTag, 1, TimeUnit.MINUTES);
        }

        Long add = redisTemplate.opsForSet().add("消息不重复:" + messageId, messageId);
        redisTemplate.expire("消息不重复:" + messageId, 5, TimeUnit.MINUTES);
        try {
            if (0 < add) {

                JSONObject jsonObject = JSONObject.parseObject(String.valueOf(realTimeDataRequest));
                String vin = jsonObject.getString("vin");
                Long userId = jsonObject.getLong("userId");
                RealTimeDataRequest request = new RealTimeDataRequest();
                request.setVin(vin);
                request.setUserId(userId);
                RealTimeJudge.addRealTime(request);
                //判断车辆是否有实时数据,如果没有则删除数据
                if (RealTimeJudge.isJudge(realTimeDataRequest.getVin())){
                    log.info("开始实时数据传输:[{}]",realTimeDataRequest.getVin());
                }
                CoupletMsgData incident = incidentMapper.queryByIncident(realTimeDataRequest.getVin());
                if (incident == null){
                    log.error("没有数据......");
                }
                redisTemplate.opsForList().rightPush("coupletMsgData", JSON.toJSONString(incident));

                channel.basicAck(deliveryTag, false);
            } else {
                log.error("消息不能重复消费:[{}]", realTimeDataRequest);
                channel.basicReject(deliveryTag, false);
            }
        } catch (IOException e) {

            log.error("消息未进入队列,传入的信息是:【{}】", realTimeDataRequest);
            String s = redisTemplate.opsForValue().get("消息不丢失:" + messageId);

            Long o = Long.valueOf(s);
            if (deliveryTag == o + 2) {
                log.error("消息已丢失,无法传入的信息是:【{}】", realTimeDataRequest);
                channel.basicNack(deliveryTag, false, false);
            } else {
                log.error("消息已丢失,已再次传入的信息是:【{}】", realTimeDataRequest);
                channel.basicNack(deliveryTag, true, false);
            }

        }


    }

}
