package com.couplet.analyze.msg.model;

import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.common.core.utils.SpringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerConfig;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.time.Duration;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Properties;

import static com.couplet.analyze.msg.utils.MsgUtils.hexToString;
import static com.couplet.analyze.msg.utils.MsgUtils.sendMsg;


/**
 * @author DongXiaoDong
 * @version 1.0
 * @date 2024/4/6 14:04
 * @description
 */
@Component
@Slf4j
public class ModelsKafkaMessage {
    private static final String TOPIC_NAME = "online";
    private static final String BOOTSTRAP_SERVERS = "39.103.133.136:9092";

    static ArrayList<String> strings = new ArrayList<>() {
        {
            add("breakdown");
            add("electronic-fence");
            add("real-time-data");
            add("stored-event");
        }
    };
    /**
     * 消费者配置
     * @return
     */
    @Scheduled(fixedDelay = 50)
    private static void consumerMessages() {
        Properties props = new Properties();
        props.put(ConsumerConfig.BOOTSTRAP_SERVERS_CONFIG, BOOTSTRAP_SERVERS);
        props.put(ConsumerConfig.GROUP_ID_CONFIG, "my-consumer-group");
        props.put(ConsumerConfig.KEY_DESERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.StringDeserializer");
        props.put(ConsumerConfig.VALUE_DESERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.StringDeserializer");

        //创建消费者
        KafkaConsumer<String, String> consumer = new KafkaConsumer<>(props);

        try {

            //订阅主题
            consumer.subscribe(Collections.singletonList(TOPIC_NAME));

            //持续消费消息
            while (true) {
                ConsumerRecords<String, String> records = consumer.poll(Duration.ofMillis(100));
                records.forEach(record -> {
                    System.out.println("接收到的数据：" + record.value());
                    String str = hexToString(record.value());
                    List<CoupletMsgData> coupletMsgDataList = sendMsg(str);
                    for (CoupletMsgData msgData : coupletMsgDataList) {
                        log.info("解析到车辆数据：{}", msgData);
                        for (String string : strings) {
                            IncidentService incidentService = SpringUtils.getBean(string);
                            incidentService.incident(msgData);
                        }
                    }
                });
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            consumer.close();
        }
    }
}
