package com.couplet.analyze.msg.service.impl;

import com.alibaba.fastjson.JSON;
import com.couplet.analyze.msg.contents.StateConstant;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.common.domain.CoupletTroubleCode;
import com.couplet.remote.RemoteTroubleService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.listener.KeyExpirationEventMessageListener;
import org.springframework.data.redis.listener.RedisMessageListenerContainer;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/2
 * @Description: 故障事件
 */
@Service("breakdown")
public class BreakdownServiceImpl extends KeyExpirationEventMessageListener implements IncidentService {

    /**
     * 设置redis存储
     */
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private RemoteTroubleService remoteTroubleService;


    private static Logger log = LoggerFactory.getLogger(BreakdownServiceImpl.class);

    public BreakdownServiceImpl(RedisMessageListenerContainer listenerContainer) {
        super(listenerContainer);
    }


    /**
     * 故障事件
     *
     * @param coupletMsgData
     */
    @Override
    public void incident(CoupletMsgData coupletMsgData) {

        log.info("故障事件开始.....");
        long l = System.currentTimeMillis();
        log.info("开始时间是："+l);
        if (StateConstant.VEHICLE_STATUS != coupletMsgData.getVehicleStatus()
                || StateConstant.CHARGING_STATUS!=coupletMsgData.getChgStatus()
                || StateConstant.OPERATING_STATUS!=coupletMsgData.getOperatingStatus()
                || StateConstant.SOC_STATUS!=coupletMsgData.getSocStatus()
                || StateConstant.CHARGING_ENERGY_STORAGE_STATUS != coupletMsgData.getChargingEnergyStorageStatus()
                || StateConstant.DRIVE_MOTOR_STATUS != coupletMsgData.getDriveMotorStatus()
                || StateConstant.POSITION_STATUS != coupletMsgData.getPositionStatus()
                || StateConstant.EAS_STATUS != coupletMsgData.getEasStatus()
                || StateConstant.PTC_STATUS != coupletMsgData.getPtcStatus()
                || StateConstant.ABS_STATUS != coupletMsgData.getAbsStatus()
                || StateConstant.MCU_STATUS != coupletMsgData.getMcuStatus()
                || StateConstant.HEATING_STATUS != coupletMsgData.getHeatingStatus()
                || StateConstant.BATTERY_STATUS != coupletMsgData.getBatteryStatus()
                || StateConstant.BATTERY_INSULATION_STATUS != coupletMsgData.getBatteryInsulationStatus()
                || StateConstant.DCDC_STATUS != coupletMsgData.getDcdcStatus()
                || StateConstant.CHG_STATUS != coupletMsgData.getChgStatus()){
                //获取过期的key
            String key = "breakdown";
            log.debug("失效+key is:"+ key);
            String value = JSON.toJSONString(coupletMsgData);
            redisTemplate.opsForSet().add(key, value);
            long expireTime = 30;
            redisTemplate.expire(key, expireTime, TimeUnit.MINUTES);
            long timeMillis = System.currentTimeMillis();
            scheduledRedis();
            log.info("故障事件结束时间："+timeMillis);
            log.info("故障事件检测结束.....");
            log.info("故障事件结束.....");
        }
        long timeMillis = System.currentTimeMillis();
        log.info("故障事件结束时间："+timeMillis);
        log.info("故障事件检测结束.....");
        log.info("故障事件结束.....");
    }

    /**
     * @return 获取事件名称
     */
    @Override
    public String getName() {
        return "breakdown";
    }

    public void scheduledRedis() {

        // Get all members of the set
        Set<String> members = redisTemplate.opsForSet().members("breakdown");
        if (members.size()!=0){
            for (String member : members){
                CoupletMsgData code = JSON.parseObject(member, CoupletMsgData.class);
                Set<String> breakdownIds = redisTemplate.opsForSet().members(code.getVin());
                if (breakdownIds.size()==0){
                    CoupletTroubleCode troubleCode = new CoupletTroubleCode();
                    troubleCode.setTroubleStartTime(new Date());
                    // 插入数据库
                    troubleCode.setTroubleTag(0);
                    troubleCode.setTroubleVin(code.getVin());
                    remoteTroubleService.newFaultData(troubleCode);
                    redisTemplate.opsForSet().add(code.getVin(), code.getVin()+":"+code);
                    long expireTime = 30;
                    redisTemplate.expire(code.getVin(), expireTime, TimeUnit.MINUTES);

                }

            }

        }

    }
}
