package com.couplet.business.server.controller;

import com.couplet.business.server.service.EmployeeService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.controller.BaseController;
import com.couplet.common.core.web.page.TableDataInfo;
import com.couplet.common.security.annotation.RequiresPermissions;
import com.couplet.common.system.domain.SysUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static com.couplet.common.core.utils.PageUtils.startPage;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 员工管理控制器
 * @date 2024/3/31 19:41
 */

@RestController
@RequestMapping("employee")
public class EmployeeController extends BaseController {

    @Autowired
    private EmployeeService employeeservice;

    /*
     * @param user:
      * @return Result<List<SysUser>>
     * @author 付凡芮
     * @description 员工列表
     * @date
     */
    @RequiresPermissions("system:user:list")
    @PostMapping("employeeList")
    public Result<TableDataInfo<SysUser>> userList (SysUser user){
        startPage();
        List<SysUser> list = employeeservice.userList(user);
        return getDataTable(list);
    }
    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 添加员工
     * @date
     */
    @PostMapping
    @RequiresPermissions("system:user:add")
    public Result insert (@RequestBody SysUser user) {
        return employeeservice.insert(user);
    }

    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 修改员工
     * @date
     */
    @RequiresPermissions("system:user:edit")
    @PutMapping
    public Result edit (@RequestBody SysUser user) {
        return employeeservice.deit(user);
    }

    /*
     * @param userIds:
      * @return Result
     * @author 付凡芮
     * @description 删除员工
     * @date
     */
    @RequiresPermissions("system:user:remove")
    @DeleteMapping("/{userIds}")
    public Result remove (@PathVariable(value = "userIds") Long[] userIds) {
        return employeeservice.remove(userIds);
    }

    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 修改员工状态
     * @date
     */
    @RequiresPermissions("system:user:edit")
    @PutMapping("/changeStatus")
    public Result changeStatus(@RequestBody SysUser user){
        return employeeservice.changeStatus(user);
    }

}
