package com.couplet.business.server.controller;

import com.couplet.business.server.service.FenceService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.controller.BaseController;
import com.couplet.common.domain.Fence;
import com.couplet.common.domain.request.FenceConfig;
import com.couplet.common.domain.request.FenceRequest;
import com.couplet.common.domain.request.FenceUpdateRequest;
import com.couplet.common.log.annotation.Log;
import com.couplet.common.log.enums.BusinessType;
import com.couplet.common.security.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Author: LiJiaYao
 * @Date: 2024/3/28
 * 电子围栏信息
 */
@RestController
@RequestMapping("/fence")
public class FenceController extends BaseController {

    /**
     * 调用服务
     */
    @Autowired
    private FenceService fenceService;


    @Log(title = "电子围栏管理", businessType = BusinessType.OTHER)
    @RequiresPermissions("couplet:fence:fenceList")
    @PostMapping("/fenceList")
    public Result<?> fenceList(@RequestBody FenceConfig fenceConfig){
        startPage();
        List<Fence> list = fenceService.pageQuery(fenceConfig);
        return getDataTable(list);
    }

    /**
     * 电子围栏新增
     * @param fenceRequest
     * @return
     *
     */
    @PostMapping("/fenceAdd")
    @RequiresPermissions("couplet:fence:fenceAdd")
    @Log(title = "电子围栏新增",businessType = BusinessType.INSERT)
    public Result<?> fenceInsert(HttpServletRequest request, @RequestBody FenceRequest fenceRequest){
//        if (!fenceService.checkFenceKeyUnique(fenceRequest.getFenceName())) {
//            return error("新增参数'" + fenceRequest.getFenceName() + "'失败，参数键名已存在");
//        }
        fenceService.fenceInsert(request,fenceRequest);
        return Result.success("新增成功");
    }

    /**
     * 电子围栏修改
     * @param fenceUpdateRequest
     * @return
     */
    @PostMapping("/fenceUpdate")
    @RequiresPermissions("couplet:fence:fenceUpdate")
    @Log(title = "电子围栏修改",businessType = BusinessType.UPDATE)
    public Result<?> fenceUpdate(@Validated  @RequestBody FenceUpdateRequest fenceUpdateRequest){
        if (!fenceService.checkFenceKeyUnique(fenceUpdateRequest.getFenceName())) {
            return error("修改参数'" + fenceUpdateRequest.getFenceName() + "'失败，参数键名已存在");
        }
        fenceService.changeFenceStatus(fenceUpdateRequest);
        return Result.success("修改成功");
    }

    /**
     * 电子围栏删除
     * @param fenceId
     * @return
     */
    @DeleteMapping("/{fenceId}")
    @RequiresPermissions("couplet:fence:fenceDelete")
    @Log(title = "电子围栏删除",businessType = BusinessType.DELETE)
    public Result<?> fenceDelete(@PathVariable Long fenceId){
        fenceService.removeByFenceId(fenceId);
        return Result.success();
    }

    /**
     * 启用停用
     * @param fenceUpdateRequest
     * @return
     */
    @PostMapping("/fenceState")
    @RequiresPermissions("couplet:fence:fenceState")
    @Log(title = "围栏启用和停用",businessType = BusinessType.OTHER)
    public Result<?> fenceState(@RequestBody FenceUpdateRequest fenceUpdateRequest){
        fenceService.changeFenceStatus(fenceUpdateRequest);
        return  success();
    }


}
