package com.couplet.business.server.controller;

import com.couplet.business.server.service.ManageServer;
import com.couplet.common.core.domain.Result;
import com.couplet.common.log.annotation.Log;
import com.couplet.common.log.enums.BusinessType;
import com.couplet.common.security.annotation.RequiresPermissions;
import com.couplet.common.system.domain.SysDept;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@RestController
@RequestMapping("/manage")
public class ManageController {


    @Autowired
    private ManageServer manageServer;


    /*
     * @param sysDept:
      * @return Result
     * @author 付凡芮
     * @description 登入后获取到企业下的所有部门
     * @date
     */
    @PostMapping("manageList")
    @RequiresPermissions("system:dept:list")
    public Result<List<SysDept>> manageList() {
        List<SysDept> sysDepts = manageServer.selectDeptList();
        return Result.success(sysDepts);
    }


    /*
     * @param sysDept:
      * @return Result
     * @author 付凡芮
     * @description 添加企业中的部门
     * @date
     */
    @RequiresPermissions("system:dept:add")
    @Log(title = "部门管理", businessType = BusinessType.INSERT)
    @PostMapping
    public Result manageInsert(@RequestBody SysDept sysDept) {
       return manageServer.insertDept(sysDept);
    }


    /*
     * @param sysDept:
      * @return Result
     * @author 付凡芮
     * @description 修改企业部门信息
     * @date
     */
    @RequiresPermissions("system:dept:edit")
    @Log(title = "部门管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result manageEdit(@RequestBody SysDept sysDept) {
     return manageServer.manageEdit(sysDept);
    }

    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 删除部门信息
     * @date
     */
    @RequiresPermissions("system:dept:remove")
    @Log(title = "部门管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{deptId}")
    public Result manageRemove(@PathVariable Long deptId){
        return manageServer.manageRemove(deptId);
    }


//    @GetMapping("/getSysDeptByDeptId/{deptId}")
//    public Result<List<SysDept>> getSysDeptByDeptId(@PathVariable(value = "deptId") Long deptId) {
//        return manageServer.getSysDeptByDeptId(deptId);
//    }

    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 根据deptId获取信息
     * @date
     */
    @RequiresPermissions("system:dept:query")
    @GetMapping(value = "/{deptId}")
    public Result getInfo(@PathVariable Long deptId) {
        return manageServer.getInfo(deptId);
    }



    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 获取企业列表
     * @date
     */
    @RequiresPermissions("system:dept:list")
    @GetMapping("/list/exclude/{deptId}")
    public Result excludeChild(@PathVariable(value = "deptId") Long deptId) {
        return manageServer.excludeChild(deptId);
    }
}
