package com.couplet.business.server.controller;

import com.couplet.business.server.service.SysTroubleService;
import com.couplet.common.core.domain.PageResult;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.controller.BaseController;
import com.couplet.common.domain.CoupletTroubleCode;
import com.couplet.common.domain.CoupletTroubleGrade;
import com.couplet.common.domain.request.TroubleResp;
import com.couplet.common.log.annotation.Log;
import com.couplet.common.log.enums.BusinessType;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author DongXiaoDong
 * @version 1.0
 * @date 2024/3/26 22:36
 * @description
 */
@RestController
@RequestMapping("trouble")
@Slf4j
public class SysTroubleController extends BaseController {
    @Autowired
    private SysTroubleService troubleService;

    /**
     * 故障码管理列表
     */
    @PostMapping("/troubleList")
    public Result<PageResult<CoupletTroubleCode>> list(@RequestBody TroubleResp troubleReq) {
        PageResult<CoupletTroubleCode> result = troubleService.selectTroubleList(troubleReq);
        return Result.success(result);
    }


    /**
     * 故障等级信息
     */
    @GetMapping("/troubleGradeList")
    public List<CoupletTroubleGrade> listGrade() {
        return troubleService.selectTroubleListByGrade();
    }

    /**
     * 新增故障码数据
     */
    @Log(title = "新增故障码数据", businessType = BusinessType.INSERT)
    @PostMapping("insertTrouble")
    public Result<?> insert(@Validated @RequestBody CoupletTroubleCode troubleAddReq) {
        return toAjax(troubleService.save(troubleAddReq));
    }

    /**
     * 修改故障码数据
     */
    @Log(title = "修改故障码数据",businessType = BusinessType.UPDATE)
    @PostMapping("updateTrouble")
    public Result<?> edit(@Validated @RequestBody CoupletTroubleCode troubleUpdReq) {
        return toAjax(troubleService.updateById(troubleUpdReq));
    }

    /**
     * 删除故障码数据
     */
    @Log(title = "删除故障码",businessType = BusinessType.DELETE)
    @GetMapping("/remove/{troubleId}")
    public Result<?> remove(@PathVariable Integer troubleId) {
        troubleService.removeById(troubleId);
        return success();
    }

    /**
     * 清空故障码信息
     */
    @PostMapping("cleanTroubleCode")
    public Result<?> cleanTroubleCode(){
        troubleService.cleanTroubleCode();
        return Result.success();
    }

    /**
     * 新增故障码数据
     */
    @Log(title = "新增故障码",businessType = BusinessType.INSERT)
    @PostMapping("/newFaultData")
    public Result<?> newFaultData(@RequestBody CoupletTroubleCode code) {
        troubleService.newFaultData(code);
        return success();
    }
}
