package com.couplet.business.server.service.impl;

import com.couplet.business.server.service.EmployeeService;
import com.couplet.common.core.constant.SecurityConstants;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.page.TableDataInfo;
import com.couplet.common.security.utils.SecurityUtils;
import com.couplet.common.system.domain.LoginUser;
import com.couplet.common.system.domain.SysUser;
import com.couplet.common.system.remote.RemoteEmployeeService;
import com.couplet.common.system.remote.RemoteUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 员工管理服务实现类
 * @date 2024/3/31 19:42
 */
@Service
public class EmployeeServiceImpl implements EmployeeService {


    @Autowired
    private RemoteEmployeeService remoteEmployeeService;
    @Autowired
    private RemoteUserService remoteUserService;

    /*
     * @param null:
      * @return null
     * @author 付凡芮
     * @description 员工列表
     * @date
     */

    @Override
    public TableDataInfo<SysUser> employeeList(SysUser user) {
        Result<TableDataInfo<SysUser>> list = remoteEmployeeService.list(user);
        TableDataInfo<SysUser> employeeList = list.getData();
        return employeeList;
    }

    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 添加员工
     * @date
     */
    @Override
    public Result insert(SysUser user) {
        return remoteEmployeeService.add(user);
    }
    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 修改员工信息
     * @date
     */
    @Override
    public Result deit(SysUser user) {
        return remoteEmployeeService.edit(user);
    }

    /*
     * @param userIds:
      * @return Result
     * @author 付凡芮
     * @description 删除员工信息
     * @date
     */
    @Override
    public Result remove(Long[] userIds) {
        return remoteEmployeeService.remove(userIds);
    }

    /*
     * @param user:
      * @return Result
     * @author 付凡芮
     * @description 修改员工状态
     * @date
     */
    @Override
    public Result changeStatus(SysUser user) {
        return remoteEmployeeService.changeStatus(user);
    }


    /*
     * @param user:
      * @return List<SysUser>
     * @author 付凡芮
     * @description 员工管理列表
     * @date
     */
    @Override
    public List<SysUser> userList(SysUser user) {
        String username = SecurityUtils.getUsername();
        Result<LoginUser> userInfo = remoteUserService.getUserInfo(username, SecurityConstants.FROM_SOURCE);
        LoginUser data = userInfo.getData();
        SysUser sysUser = data.getSysUser();
        Long deptId = sysUser.getDeptId();
        Result<List<SysUser>> listResult = remoteEmployeeService.userList(deptId);
        List<SysUser> userList = listResult.getData();
        return userList;
    }

}
