package com.couplet.business.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.couplet.business.server.mapper.FenceMapper;
import com.couplet.business.server.service.FenAndLogoService;
import com.couplet.business.server.service.FenceService;
import com.couplet.common.domain.Fence;
import com.couplet.common.domain.request.FenceConfig;
import com.couplet.common.domain.request.FenceRequest;
import com.couplet.common.domain.request.FenceUpdateRequest;
import com.couplet.common.security.utils.SecurityUtils;
import com.couplet.mq.remote.RemoteFenceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @Author: LiJiaYao
 * @Date: 2024/3/28
 */
@Service
public class FenceServiceImpl extends ServiceImpl<FenceMapper, Fence> implements FenceService {

    /**
     * 调用围栏mapper
     */
    @Autowired
    private FenceMapper fenceMapper;

    /**
     * 调用围栏和标识中间表
     */
    @Autowired
    private FenAndLogoService fenAndLogoService;
    /**
     * 注入redis模板
     */
    @Autowired
    private StringRedisTemplate redisTemplate;
    /**
     * 远程调用队列服务
     */
    @Autowired
    private RemoteFenceService remoteFenceService;

    @Override
    public List<Fence> pageQuery(FenceConfig fenceConfig) {
        List<Fence> list = fenceMapper.pageQuery(fenceConfig);
        return list;
    }

    @Override
    public void changeFenceStatus(FenceUpdateRequest fenceUpdateRequest) {

        String username = SecurityUtils.getUsername();
        fenceUpdateRequest.setCrateName(username);
        fenceMapper.changeFence(fenceUpdateRequest);
        /**
         * 电子围栏发送改变
         */
        redisTemplate.opsForValue().set("changeFenceStatus", JSON.toJSONString(fenceUpdateRequest), 10, TimeUnit.MINUTES);

        remoteFenceService.fenceQueue(fenceUpdateRequest);
    }

    /**
     * 业务实现:添加围栏
     *
     * @param request
     * @param fenceRequest
     */
    @Override
    public void fenceInsert(HttpServletRequest request, FenceRequest fenceRequest) {
        String username = SecurityUtils.getUsername();
        fenceRequest.setCrateName(username);
        //先添加围栏
        fenceMapper.insertFence(fenceRequest);
        String[] logoIds = fenceRequest.getLogoIds();
        String[] parts = new String[0];
        for (String logoId : logoIds) {
            //把前台传入的字符串分割成数组
            parts = logoId.split(",");
            //再添加围栏和标识中间表
            fenAndLogoService.addBach(fenceRequest.getFenceId(), parts);
        }
        /**
        * 电子围栏发送改变
        */
        redisTemplate.opsForValue().set("fenceInsert", JSON.toJSONString(fenceRequest), 10, TimeUnit.MINUTES);
    }

    @Override
    public void removeByFenceId(Long fenceId) {
        fenceMapper.removeByFenceId(fenceId);
        /**
         * 电子围栏发送改变
         */
        redisTemplate.opsForValue().set("removeByFenceId", JSON.toJSONString(fenceId), 10, TimeUnit.MINUTES);

    }

    @Override
    public boolean checkFenceKeyUnique(String fenceName) {
        return fenceMapper.checkFenceKeyUnique(fenceName);
    }
}
