package com.couplet.business.server.service.impl;

import com.couplet.business.server.service.ManageServer;
import com.couplet.common.core.domain.Result;
import com.couplet.common.security.utils.SecurityUtils;
import com.couplet.common.system.domain.LoginUser;
import com.couplet.common.system.domain.SysDept;
import com.couplet.common.system.remote.RemoteDeptService;
import com.couplet.common.system.remote.RemoteUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 管理企业业务层
 * @date 2024/3/27 15:34
 */
@Service
public class ManageServiceImpl implements ManageServer {

    @Autowired
    private RemoteDeptService remoteDeptService;
    @Autowired
    private RemoteUserService remoteUserService;

    /*
     * @param :
      * @return List<SysDept>
     * @author 付凡芮
     * @description 企业管理列表
     * @date
     */
    @Override
    public List<SysDept> selectDeptList() {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        Long deptId = loginUser.getSysUser().getDeptId();
        Result<List<SysDept>> sysDeptByDeptId = remoteDeptService.getSysDeptByDeptId(deptId);
        List<SysDept> dept = sysDeptByDeptId.getData();
        return dept;
    }

    /*
     * @param sysDept:
      * @return Result
     * @author 付凡芮
     * @description 添加企业部门
     * @date
     */
    @Override
    public Result insertDept(SysDept sysDept) {

        return remoteDeptService.add(sysDept);
    }

    /*
     * @param sysDept:
      * @return Result
     * @author 付凡芮
     * @description 修改企业部门信息
     * @date
     */
    @Override
    public Result manageEdit(SysDept sysDept) {
        return remoteDeptService.edit(sysDept);
    }

    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 删除企业部门信息
     * @date
     */
    @Override
    public Result manageRemove(Long deptId) {
        return remoteDeptService.remove(deptId);
    }

    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 获取企业信息
     * @date
     */
    @Override
    public Result getInfo(Long deptId) {
        return remoteDeptService.getInfo(deptId);
    }

    /*
     * @param deptId:
      * @return Result
     * @author 付凡芮
     * @description 获取企业部门
     * @date
     */
    @Override
    public Result excludeChild(Long deptId) {
        return remoteDeptService.excludeChild(deptId);
    }
}
