package com.couplet.business.server.service.impl;

import com.couplet.business.server.service.VehicleManageService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.domain.Vehicle;
import com.couplet.common.domain.VehicleMiddle;
import com.couplet.common.security.utils.SecurityUtils;
import com.couplet.remote.RemoteVehicleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 车辆管理服务实现类
 * @date 2024/4/2 9:05
 */
@Service
public class VehicleManageServiceImpl implements VehicleManageService {


    @Autowired
    private RemoteVehicleService remoteVehicleService;

    /*
     * @description: 车辆管理列表
     * @param: []
     * @return: com.couplet.common.core.domain.Result<java.util.List<com.couplet.common.system.domain.Vehicle>>
     */
    @Override
    public List<Vehicle> VehicleManageList() {
        Long userId = SecurityUtils.getUserId();
        Result<List<Vehicle>> listResult = remoteVehicleService.UserUnderTheVehicleList(userId);
        List<Vehicle> list = listResult.getData();
        return list;
    }

    /*
     * @param middleId:
      * @return Result
     * @author 付凡芮
     * @description 删除员工管理车辆
     * @date
     */
    @Override
    public Result deleteVehicle(Long middleId) {
        Result<Integer> integerResult = remoteVehicleService.deleteVehicle(middleId);
        Integer resultData = integerResult.getData();

        return resultData==1?Result.success():Result.error("删除失败");
    }

    /*
     * @param middle:
      * @return Result
     * @author 付凡芮
     * @description 添加车辆
     * @date
     */
    @Override
    public Result addVehicle(VehicleMiddle middle) {
        Long userId = SecurityUtils.getUserId();
        middle.setUserId(userId);
        Result<Integer> integerResult = remoteVehicleService.addVehicle(middle);
        Integer resultData = integerResult.getData();
        return resultData==1?Result.success():Result.error("添加失败");
    }

    @Override
    public List<Vehicle> vehicleAll() {
        Result<List<Vehicle>> listResult = remoteVehicleService.VehicleManageList();
        return listResult.getData();
    }


}
