package com.couplet.business.server.time;

import com.couplet.business.server.service.VehicleService;
import com.couplet.common.domain.Vehicle;
import com.couplet.common.domain.request.VehicleListParams;
import com.couplet.common.redis.service.RedisService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ProjectName: five-groups-couplet
 * @Author: LiuYunHu
 * @CreateTime: 2024/4/4
 * @Description: 车辆定时器
 */
@Component
@Slf4j
public class Timer {
    //redis
    @Autowired
    private StringRedisTemplate redis;
    //查询车辆列表
    @Autowired
    private VehicleService vehicleService;


    //判断车辆是否下线
    @Scheduled(cron = "* * * * * *")
    public void outLine() {
        log.info("定时器启动");

        //先查询车辆列表
        List<Vehicle> list = vehicleService.list(new VehicleListParams(null, null, null, null));
        for (Vehicle vehicle : list) {
            //只针对已经上线的车辆
            if (redis.hasKey(vehicle.getVin())) {

                //如果vin的缓存 时间还剩一秒，则判断为已经下线
                if (redis.getExpire(vehicle.getVin()) <= 3) {
                    log.info(vehicle.getVin() + "的车辆已经下线");

                    //执行修改下线状态的方法
                    Integer i = vehicleService.onOrOutLineByVIN(vehicle.getVin(), 0);

//                    if (0 == 1) {
//                        log.error("下线状态修改失败");
//                    }

                    log.info("下线状态修改成功");
                }
            }
        }

    }

}
