package com.couplet.mq.controller;

import com.couplet.common.core.utils.uuid.IdUtils;
import com.couplet.common.domain.request.FenceUpdateRequest;
import com.couplet.common.domain.request.RealTimeDataRequest;
import com.couplet.common.security.utils.SecurityUtils;
import com.couplet.mq.config.RabbitMQConfig;
import com.couplet.mq.domain.User;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @ProjectName: five-groups-couplet
 * @Author: LiuYunHu
 * @CreateTime: 2024/3/29
 * @Description: MQController类
 */
@RestController
@RequestMapping("/mq")
@Slf4j
public class MqController {
    // 通过注入的方式获取队列名、交换机名和路由键
    //队列名
    @Value("queueName")
    public String queueName;
    @Value("finByVinQueueName")
    public String finByVinQueueName;
    //交换机
    @Value("exchangeName")
    public String exchangeName;

    //路由键
    @Value("routingKey")
    public String routingKey;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    /*
     * @Author: LiuYunHu
     * @Date: 2024/4/1 19:58
     * @Description: 消息发送者
     * @Param: [data]
     * @Return: void
     **/
    @PostMapping("/sout")
    //接收json字符串
    public void sout(@RequestBody User param) {
        rabbitTemplate.convertAndSend(exchangeName, routingKey, param, message -> {
                    message.getMessageProperties().setMessageId(IdUtils.randomUUID());
                    return message;
                }, new CorrelationData(IdUtils.randomUUID())
        );

    }


    @PostMapping("findByVin")
    public void postFindByVin(@RequestBody RealTimeDataRequest request){
        Long userId = SecurityUtils.getUserId();
        request.setUserId(userId);
        rabbitTemplate.convertAndSend(exchangeName, routingKey, request, message -> {
                    message.getMessageProperties().setMessageId(IdUtils.randomUUID());
                    return message;
                }, new CorrelationData(IdUtils.randomUUID())
        );
    }
    @PostMapping("fenceQueue")
    public void fenceQueue(@RequestBody FenceUpdateRequest fenceUpdateRequest){
        rabbitTemplate.convertAndSend(RabbitMQConfig.FENCE_EXCHANGE, RabbitMQConfig.FENCE_ROUTINGKEY, fenceUpdateRequest, message -> {
                    message.getMessageProperties().setMessageId(IdUtils.randomUUID());
                    return message;
                }, new CorrelationData(IdUtils.randomUUID())
        );
    }
}
