package com.couplet.mq.service;

import com.couplet.mq.domain.User;
import com.rabbitmq.client.Channel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.concurrent.TimeUnit;

/**
 * @ProjectName: five-groups-couplet
 * @Author: LiuYunHu
 * @CreateTime: 2024/3/28
 * @Description: MQ消费者类
 */

@Component
@Slf4j
@SuppressWarnings("all")
@RabbitListener(queues = "queueName")
public class Consumer {
    @Autowired
    private StringRedisTemplate redis;

    /* 线程池执行

    //创建一个定长线程池
    private final Executor executor = Executors.newFixedThreadPool(5);

    @Async
    @RabbitHandler
    public void process(User param, Channel channel, Message message) {
        executor.execute(() -> {
            try {
                handleMessage(param, channel, message);
            } catch (IOException e) {
                log.error("处理消息失败：{}", e);
            }
        });
    }

    //处理信息的方法
    private void handleMessage(User param, Channel channel, Message message) throws IOException {
        log.info("消费者收到消息为：{},{}" + param, message.getMessageProperties().getDeliveryTag());

        long deliveryTag = message.getMessageProperties().getDeliveryTag();
        String messageId = message.getMessageProperties().getMessageId();

        if (!redis.hasKey("value:" + messageId)) {
            redis.opsForValue().set("value:" + messageId, "" + deliveryTag, 5, TimeUnit.MINUTES);
        }

        // 1 添加成功新数据  0已有重复值,不允许再添加
        Long add = redis.opsForSet().add("set:" + messageId, "set:" + messageId);
        //过期时间
        redis.expire("set:" + messageId, 5, TimeUnit.MINUTES);


        try {
            if (add == 1) {
                //第一次    消费
                System.out.println("*****************************");
                System.out.println("消费者收到消息：" + param);
                System.out.println("*****************************");
                log.info("消费结束");

                channel.basicAck(deliveryTag, false);

            } else {
                //重复消费
                log.error("重复消费");
                channel.basicReject(deliveryTag, false);

                //删除缓存
                redis.opsForSet().remove("set:" + messageId, "set:" + messageId);
            }


        } catch (Exception e) {
            log.error("消息没有成功消费！");

            String s = redis.opsForValue().get("value:" + messageId);

            long oldTag = Long.parseLong(s);

            if (deliveryTag == (oldTag + 2)) {
                log.error("确实消费不了，不入队了！");
                channel.basicNack(deliveryTag, false, false);
            } else {
                log.info("消息消费失败，重新入队");
                channel.basicNack(deliveryTag, false, true);
            }
        }

    }

**/

    @RabbitHandler
    public void process(User param, Channel channel, Message message) throws IOException {
        log.info("消费者收到消息为：{},{}" + param, message.getMessageProperties().getDeliveryTag());

        long deliveryTag = message.getMessageProperties().getDeliveryTag();
        String messageId = message.getMessageProperties().getMessageId();

        if (!redis.hasKey("value:" + messageId)) {
            redis.opsForValue().set("value:" + messageId, "" + deliveryTag, 5, TimeUnit.MINUTES);
        }

        // 1 添加成功新数据  0已有重复值,不允许再添加
        Long add = redis.opsForSet().add("set:" + messageId, "set:" + messageId);
        //过期时间
        redis.expire("set:" + messageId, 5, TimeUnit.MINUTES);


        try {
            if (add == 1) {
                //第一次    消费
                System.out.println("*****************************");
                System.out.println("消费者收到消息：" + param);
                System.out.println("*****************************");
                log.info("消费结束");

                //确认消费
                channel.basicAck(deliveryTag, false);

            } else {
                //重复消费
                log.error("重复消费");
                //拒绝消费
                channel.basicReject(deliveryTag, false);

                //删除缓存
                redis.opsForSet().remove("set:" + messageId, "set:" + messageId);
            }


        } catch (Exception e) {
            log.error("消息没有成功消费！");

            String s = redis.opsForValue().get("value:" + messageId);

            long oldTag = Long.parseLong(s);

            if (deliveryTag == (oldTag + 2)) {
                log.error("确实消费不了，不入队了！");


                //拒绝消费
                channel.basicNack(deliveryTag, false, false);
            } else {
                log.info("消息消费失败，重新入队");
                //重新入队
                channel.basicNack(deliveryTag, false, true);
            }
        }
    }
}
